@@ -26,6 +26,7 @@ def _create_backward_assignments_tf_mad(self, diff_fields_prefix):
     """
 
     forward_assignments = self._forward_assignments
+
     if hasattr(forward_assignments, 'new_without_subexpressions'):
         forward_assignments = forward_assignments.new_without_subexpressions()
     if hasattr(forward_assignments, 'main_assignments'):
@@ -249,7 +250,6 @@ Backward:
             self._forward_input_fields = list(sorted(forward_assignments.free_fields, key=lambda x: str(x)))
             self._forward_output_fields = list(sorted(forward_assignments.bound_fields, key=lambda x: str(x)))
             self._backward_assignments = backward_assignments
-            self._backward_field_map = None
             self._backward_input_fields = list(sorted(backward_assignments.free_fields, key=lambda x: str(x)))
             self._backward_output_fields = list(sorted(backward_assignments.bound_fields, key=lambda x: str(x)))
         else:
@@ -261,22 +261,16 @@ Backward:
                 self._backward_field_map = None
                 backward_assignments = _create_backward_assignments_tf_mad(self, diff_fields_prefix)
                 self._backward_assignments = backward_assignments
-                if self._backward_field_map:
-                    self._backward_input_fields = [
-                        self._backward_field_map[f] for f in self._forward_output_fields]
-                    self._backward_output_fields = [
-                        self._backward_field_map[f] for f in self._forward_input_fields]
-                else:
-                    self._forward_assignments = forward_assignments
-                    self._forward_read_accesses = None
-                    self._forward_write_accesses = None
-                    self._forward_input_fields = list(sorted(forward_assignments.free_fields, key=lambda x: str(x)))
-                    self._forward_output_fields = list(sorted(forward_assignments.bound_fields, key=lambda x: str(x)))
-                    self._backward_assignments = backward_assignments
-                    self._backward_field_map = None
-                    self._backward_input_fields = list(sorted(backward_assignments.free_fields, key=lambda x: str(x)))
-                    self._backward_output_fields = list(sorted(backward_assignments.bound_fields, key=lambda x: str(x)))
-                    self._backward_field_map = None
+
+                self._forward_assignments = forward_assignments
+                self._forward_read_accesses = None
+                self._forward_write_accesses = None
+                self._forward_input_fields = list(sorted(forward_assignments.free_fields, key=lambda x: str(x)))
+                self._forward_output_fields = list(sorted(forward_assignments.bound_fields, key=lambda x: str(x)))
+                self._backward_assignments = backward_assignments
+                self._backward_field_map = None
+                self._backward_input_fields = list(sorted(backward_assignments.free_fields, key=lambda x: str(x)))
+                self._backward_output_fields = list(sorted(backward_assignments.bound_fields, key=lambda x: str(x)))
             else:
                 raise NotImplementedError()
             # else:
@@ -306,13 +300,35 @@ Backward:
         self._forward_input_fields = list(forward_assignments.free_fields)
         self._forward_output_fields = list(forward_assignments.bound_fields)
         self._backward_assignments = backward_assignments
-        self._backward_field_map = None
         self._backward_input_fields = list(backward_assignments.free_fields)
         self._backward_output_fields = list(backward_assignments.bound_fields)
-        self._backward_field_map = None
+        self._forward_ast_cpu = None
+        self._backward_ast_cpu = None
+        self._forward_ast_gpu = None
+        self._backward_ast_gpu = None
+        self._forward_kernel_cpu = None
+        self._backward_kernel_cpu = None
+        self._forward_kernel_gpu = None
+        self._backward_kernel_gpu = None
+        self._constant_fields = None
+        self._time_constant_fields = None
+        self._kwargs = state['kwargs']
+        self.op_name = ''
+        self._forward_ast_cpu = None
+        self._backward_ast_cpu = None
+        self._forward_ast_gpu = None
+        self._backward_ast_gpu = None
+        self._forward_kernel_cpu = None
+        self._backward_kernel_cpu = None
+        self._forward_kernel_gpu = None
+        self._backward_kernel_gpu = None
+        self._do_common_subexpression_elimination = None
+        self._boundary_handling = 'ZEROS'
 
     def __getstate__(self):
-        return {'forward_assignments': self._forward_assignments, 'backward_assignments': self.backward_assignments}
+        return {'forward_assignments': self.forward_assignments,
+                'backward_assignments': self.backward_assignments,
+                'kwargs': self._kwargs}
 
     def _create_backward_assignments(self, diff_fields_prefix):
         """
@@ -472,6 +488,7 @@ Backward:
 
     @property
     def backward_ast_cpu(self):
+        assert self._backward_assignments, 'No backward assignments!'
         if not self._backward_ast_cpu:
             if (self._boundary_handling == AutoDiffBoundaryHandling.ZEROS or
                     self._boundary_handling == AutoDiffBoundaryHandling.VALID):
@@ -488,6 +505,7 @@ Backward:
 
     @property
     def backward_ast_gpu(self):
+        assert self._backward_assignments, 'No backward assignments!'
         if not self._backward_ast_gpu:
             if (self._boundary_handling == AutoDiffBoundaryHandling.ZEROS or
                     self._boundary_handling == AutoDiffBoundaryHandling.VALID):
@@ -526,10 +544,6 @@ Backward:
             self._backward_kernel_gpu = self.backward_ast_gpu.compile()
         return self._backward_kernel_gpu
 
-    @property
-    def backward_fields_map(self):
-        return self._backward_field_map
-
     @property
     def backward_input_fields(self):
         return self._backward_input_fields
